<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Christopher Smith <chris@jalakai.co.uk>
 * @author Thanos Massias <tm@thriasio.gr>
 * @author Αθανάσιος Νταής <homunculus@wana.gr>
 * @author Konstantinos Koryllos <koryllos@gmail.com>
 * @author George Petsagourakis <petsagouris@gmail.com>
 * @author Petros Vidalis <pvidalis@gmail.com>
 * @author Vasileios Karavasilis vasileioskaravasilis@gmail.com
 * @author Zacharias Sdregas <zsdregas@sch.gr>
 */
$lang['menu']                  = 'Ρυθμίσεις';
$lang['error']                 = 'Οι ρυθμίσεις σας δεν έγιναν δεκτές λόγω λανθασμένης τιμής κάποιας ρύθμισης. Διορθώστε την λάθος τιμή και προσπαθήστε ξανά.
                                      <br />Η λανθασμένη τιμή υποδεικνύεται με κόκκινο πλαίσιο.';
$lang['updated']               = 'Επιτυχής τροποποίηση ρυθμίσεων.';
$lang['nochoice']              = '(δεν υπάρχουν άλλες διαθέσιμες επιλογές)';
$lang['locked']                = 'Το αρχείο ρυθμίσεων δεν μπορεί να τροποποιηθεί. <br />Εάν αυτό δεν είναι επιθυμητό, διορθώστε τα δικαιώματα πρόσβασης του αρχείου ρυθμίσεων';
$lang['danger']                = 'Κίνδυνος: Η αλλαγή αυτής της επιλογής θα μπορούσε να αποτρέψει την πρόσβαση στο wiki και στις ρυθμίσεις του.';
$lang['warning']               = 'Προσοχή: Η αλλαγή αυτής της επιλογής θα μπορούσε να προκαλέσει ανεπιθύμητη συμπεριφορά.';
$lang['security']              = 'Προσοχή: Η αλλαγή αυτής της επιλογής θα μπορούσε να προκαλέσει προβλήματα ασφαλείας.';
$lang['_configuration_manager'] = 'Ρυθμίσεις';
$lang['_header_dokuwiki']      = 'Ρυθμίσεις DokuWiki';
$lang['_header_plugin']        = 'Ρυθμίσεις Επεκτάσεων';
$lang['_header_template']      = 'Ρυθμίσεις Προτύπων παρουσίασης';
$lang['_header_undefined']     = 'Διάφορες Ρυθμίσεις';
$lang['_basic']                = 'Βασικές Ρυθμίσεις';
$lang['_display']              = 'Ρυθμίσεις Εμφάνισης';
$lang['_authentication']       = 'Ρυθμίσεις Ασφαλείας';
$lang['_anti_spam']            = 'Ρυθμίσεις Anti-Spam';
$lang['_editing']              = 'Ρυθμίσεις Σύνταξης σελίδων';
$lang['_links']                = 'Ρυθμίσεις Συνδέσμων';
$lang['_media']                = 'Ρυθμίσεις Αρχείων';
$lang['_notifications']        = 'Ρυθμίσεις ενημερώσεων';
$lang['_syndication']          = 'Ρυθμίσεις σύνδεσης';
$lang['_advanced']             = 'Ρυθμίσεις για Προχωρημένους';
$lang['_network']              = 'Ρυθμίσεις Δικτύου';
$lang['_msg_setting_undefined'] = 'Δεν έχουν οριστεί metadata.';
$lang['_msg_setting_no_class'] = 'Δεν έχει οριστεί κλάση.';
$lang['_msg_setting_no_default'] = 'Δεν υπάρχει τιμή εξ ορισμού.';
$lang['title']                 = 'Τίτλος Wiki';
$lang['start']                 = 'Ονομασία αρχικής σελίδας';
$lang['lang']                  = 'Γλώσσα';
$lang['template']              = 'Πρότυπο προβολής';
$lang['tagline']               = 'Tagline';
$lang['sidebar']               = 'Sidebar page name';
$lang['license']               = 'Κάτω από ποια άδεια θέλετε να δημοσιευτεί το υλικό σας?';
$lang['savedir']               = 'Φάκελος για την αποθήκευση δεδομένων';
$lang['basedir']               = 'Αρχικός Φάκελος';
$lang['baseurl']               = 'Αρχικό URL';
$lang['cookiedir']             = 'Διαδρομή cookie. Αφήστε την κενή για την χρησιμοποίηση της αρχικής URL.';
$lang['dmode']                 = 'Δικαιώματα πρόσβασης δημιουργούμενων φακέλων';
$lang['fmode']                 = 'Δικαιώματα πρόσβασης δημιουργούμενων αρχείων';
$lang['allowdebug']            = 'Δεδομένα εκσφαλμάτωσης (debug) <b>απενεργοποιήστε τα εάν δεν τα έχετε ανάγκη!</b>';
$lang['recent']                = 'Αριθμός πρόσφατων αλλαγών ανά σελίδα';
$lang['recent_days']           = 'Πόσο παλιές αλλαγές να εμφανίζονται (ημέρες)';
$lang['breadcrumbs']           = 'Αριθμός συνδέσμων ιστορικού';
$lang['youarehere']            = 'Εμφάνιση ιεραρχικής προβολής τρέχουσας σελίδας';
$lang['fullpath']              = 'Εμφάνιση πλήρους διαδρομής σελίδας στην υποκεφαλίδα';
$lang['typography']            = 'Μετατροπή ειδικών χαρακτήρων στο τυπογραφικό ισοδύναμό τους';
$lang['dformat']               = 'Μορφή ημερομηνίας (βλέπε την <a href="http://php.net/strftime">strftime</a> function της PHP)';
$lang['signature']             = 'Υπογραφή';
$lang['showuseras']            = 'Τι να εμφανίζεται όταν φαίνεται ο χρήστης που τροποποίησε τελευταίος μία σελίδα';
$lang['toptoclevel']           = 'Ανώτατο επίπεδο πίνακα περιεχομένων σελίδας';
$lang['tocminheads']           = 'Ελάχιστος αριθμός κεφαλίδων για την δημιουργία πίνακα περιεχομένων - TOC';
$lang['maxtoclevel']           = 'Μέγιστο επίπεδο για πίνακα περιεχομένων σελίδας';
$lang['maxseclevel']           = 'Μέγιστο επίπεδο για εμφάνιση της επιλογής τροποποίησης επιπέδου';
$lang['camelcase']             = 'Χρήση CamelCase στους συνδέσμους';
$lang['deaccent']              = 'Αφαίρεση σημείων στίξης από ονόματα σελίδων';
$lang['useheading']            = 'Χρήση κεφαλίδας πρώτου επιπέδου σαν τίτλο συνδέσμων';
$lang['sneaky_index']          = 'Εξ ορισμού, η εφαρμογή DokuWiki δείχνει όλους τους φακέλους στην προβολή Καταλόγου. Ενεργοποιώντας αυτή την επιλογή, δεν θα εμφανίζονται οι φάκελοι για τους οποίους ο χρήστης δεν έχει δικαιώματα ανάγνωσης αλλά και οι υπο-φάκελοί τους ανεξαρτήτως δικαιωμάτων πρόσβασης.';
$lang['hidepages']             = 'Φίλτρο απόκρυψης σελίδων (regular expressions)';
$lang['useacl']                = 'Χρήση Λίστας Δικαιωμάτων Πρόσβασης (ACL)';
$lang['autopasswd']            = 'Αυτόματη δημιουργία κωδικού χρήστη';
$lang['authtype']              = 'Τύπος πιστοποίησης στοιχείων χρήστη';
$lang['passcrypt']             = 'Μέθοδος κρυπτογράφησης κωδικού χρήστη';
$lang['defaultgroup']          = 'Προεπιλεγμένη ομάδα χρηστών';
$lang['superuser']             = 'Υπερ-χρήστης - μία ομάδα ή ένας χρήστης με πλήρη δικαιώματα πρόσβασης σε όλες τις σελίδες και όλες τις λειτουργίες ανεξάρτητα από τις ρυθμίσεις των Λιστών Δικαιωμάτων Πρόσβασης (ACL)';
$lang['manager']               = 'Διαχειριστής - μία ομάδα ή ένας χρήστης με δικαιώματα πρόσβασης σε ορισμένες από τις λειτουργίες της εφαρμογής';
$lang['profileconfirm']        = 'Να απαιτείται ο κωδικός χρήστη για την επιβεβαίωση αλλαγών στο προφίλ χρήστη';
$lang['rememberme']            = 'Να επιτρέπονται τα cookies λογαρισμού χρήστη αορίστου χρόνου (Απομνημόνευση στοιχείων λογαριασμού)';
$lang['disableactions']        = 'Απενεργοποίηση λειτουργιών DokuWiki';
$lang['disableactions_check']  = 'Έλεγχος';
$lang['disableactions_subscription'] = 'Εγγραφή/Διαγραφή χρήστη';
$lang['disableactions_wikicode'] = 'Προβολή κώδικα σελίδας';
$lang['disableactions_other']  = 'Άλλες λειτουργίες (διαχωρίστε τις με κόμμα)';
$lang['auth_security_timeout'] = 'Διάρκεια χρόνου για ασφάλεια πιστοποίησης (δευτερόλεπτα)';
$lang['securecookie']          = 'Τα cookies που έχουν οριστεί μέσω HTTPS πρέπει επίσης να αποστέλλονται μόνο μέσω HTTPS από τον φυλλομετρητή? Απενεργοποιήστε αυτή την επιλογή όταν μόνο η είσοδος στο wiki σας διασφαλίζεται μέσω SSL αλλά η περιήγηση γίνεται και χωρίς αυτό.';
$lang['remote']                = 'Ενεργοποίησης απομακρυσμένης προγραμματιστικής διεπαφής εφαρμογών (API). Με αυτό τον τρόπο επιτρέπεται η πρόσβαση στο wiki με το XML-RPC ή με άλλα πρωτόκολλα επικοινωνίας.';
$lang['remoteuser']            = 'Απενεργοποίησης απομακρυσμένης προγραμματιστικής διεπαφής εφαρμογών (API). Αφήστε το κενό για να είναι δυνατή η πρόσβαση στον οποιοδήποτε.';
$lang['usewordblock']          = 'Χρήστη λίστα απαγορευμένων λέξεων για καταπολέμηση του spam';
$lang['relnofollow']           = 'Χρήση rel="nofollow"';
$lang['indexdelay']            = 'Χρόνος αναμονής προτού επιτραπεί σε μηχανές αναζήτησης να ευρετηριάσουν μια τροποποιημένη σελίδα (sec)';
$lang['mailguard']             = 'Κωδικοποίηση e-mail διευθύνσεων';
$lang['iexssprotect']          = 'Έλεγχος μεταφορτώσεων για πιθανώς επικίνδυνο κώδικα JavaScript ή HTML';
$lang['usedraft']              = 'Αυτόματη αποθήκευση αντιγράφων κατά την τροποποίηση σελίδων';
$lang['htmlok']                = 'Να επιτρέπεται η ενσωμάτωση HTML';
$lang['phpok']                 = 'Να επιτρέπεται η ενσωμάτωση PHP';
$lang['locktime']              = 'Μέγιστος χρόνος κλειδώματος αρχείου υπό τροποποίηση (sec)';
$lang['cachetime']             = 'Μέγιστη ηλικία cache (sec)';
$lang['target____wiki']        = 'Παράθυρο-στόχος για εσωτερικούς συνδέσμους';
$lang['target____interwiki']   = 'Παράθυρο-στόχος για συνδέσμους interwiki';
$lang['target____extern']      = 'Παράθυρο-στόχος για εξωτερικούς σθνδέσμους';
$lang['target____media']       = 'Παράθυρο-στόχος για συνδέσμους αρχείων';
$lang['target____windows']     = 'Παράθυρο-στόχος για συνδέσμους σε Windows shares';
$lang['mediarevisions']        = 'Ενεργοποίηση Mediarevisions;';
$lang['refcheck']              = 'Πριν τη διαγραφή ενός αρχείου να ελέγχεται η ύπαρξη σελίδων που το χρησιμοποιούν';
$lang['gdlib']                 = 'Έκδοση βιβλιοθήκης GD';
$lang['im_convert']            = 'Διαδρομή προς το εργαλείο μετατροπής εικόνων του ImageMagick';
$lang['jpg_quality']           = 'Ποιότητα συμπίεσης JPG (0-100)';
$lang['fetchsize']             = 'Μέγιστο μέγεθος (σε bytes) εξωτερικού αρχείου που επιτρέπεται να μεταφέρει η fetch.php';
$lang['subscribers']           = 'Να επιτρέπεται η εγγραφή στην ενημέρωση αλλαγών σελίδας';
$lang['subscribe_time']        = 'Χρόνος μετά τον οποίο οι λίστες ειδοποιήσεων και τα συνοπτικά θα αποστέλλονται (δευτερόλεπτα). Αυτό θα πρέπει να είναι μικρότερο από τον χρόνο που έχει η ρύθμιση recent_days.';
$lang['notify']                = 'Αποστολή ενημέρωσης για αλλαγές σε αυτή την e-mail διεύθυνση';
$lang['registernotify']        = 'Αποστολή ενημερωτικών μηνυμάτων σε αυτή την e-mail διεύθυνση κατά την εγγραφή νέων χρηστών';
$lang['mailfrom']              = 'e-mail διεύθυνση αποστολέα για μηνύματα από την εφαρμογή';
$lang['mailprefix']            = 'Πρόθεμα θέματος που να χρησιμοποιείται για τα αυτόματα μηνύματα ηλεκτρονικού ταχυδρομείου.';
$lang['htmlmail']              = 'Αποστολή οπτικά καλύτερου, αλλά μεγαλύτερου σε μέγεθος email με χρήση HTML. Απενεργοποιήστε το για αποστέλλονται μόνο email απλού κειμένου.';
$lang['sitemap']               = 'Δημιουργία Google sitemap (ημέρες)';
$lang['rss_type']              = 'Τύπος XML feed';
$lang['rss_linkto']            = 'Τύπος συνδέσμων στο XML feed';
$lang['rss_content']           = 'Τι να εμφανίζεται στα XML feed items?';
$lang['rss_update']            = 'Χρόνος ανανέωσης XML feed (sec)';
$lang['rss_show_summary']      = 'Να εμφανίζεται σύνοψη του XML feed στον τίτλο';
$lang['rss_media']             = 'Τι είδους αλλαγές πρέπει να εμφανίζονται στο XLM feed;';
$lang['updatecheck']           = 'Έλεγχος για ύπαρξη νέων εκδόσεων και ενημερώσεων ασφαλείας της εφαρμογής? Απαιτείται η σύνδεση με το update.dokuwiki.org για να λειτουργήσει σωστά αυτή η επιλογή.';
$lang['userewrite']            = 'Χρήση ωραίων URLs';
$lang['useslash']              = 'Χρήση slash σαν διαχωριστικό φακέλων στα URLs';
$lang['sepchar']               = 'Διαχωριστικός χαρακτήρας για κανονικοποίηση ονόματος σελίδας';
$lang['canonical']             = 'Πλήρη και κανονικοποιημένα URLs';
$lang['fnencode']              = 'Μέθοδος κωδικοποίησης για ονόματα αρχείων μη-ASCII';
$lang['autoplural']            = 'Ταίριασμα πληθυντικού στους συνδέσμους';
$lang['compression']           = 'Μέθοδος συμπίεσης για αρχεία attic';
$lang['gzip_output']           = 'Χρήση gzip Content-Encoding για την xhtml';
$lang['compress']              = 'Συμπίεση αρχείων CSS και javascript';
$lang['cssdatauri']            = 'Το μέγεθος σε bytes στο οποίο οι εικόνες που αναφέρονται σε CSS αρχεία θα πρέπει να είναι ενσωματωμένες για τη μείωση των απαιτήσεων μιας κεφαλίδας αίτησης HTTP . Αυτή η τεχνική δεν θα λειτουργήσει σε IE <8! <code> 400 </code> με <code> 600 </code> bytes είναι μια καλή τιμή. Ορίστε την τιμή <code> 0 </code> για να το απενεργοποιήσετε.';
$lang['send404']               = 'Αποστολή "HTTP 404/Page Not Found" για σελίδες που δεν υπάρχουν';
$lang['broken_iua']            = 'Η συνάρτηση ignore_user_abort δεν λειτουργεί σωστά στο σύστημά σας? Σε αυτή την περίπτωση μπορεί να μην δουλεύει σωστά η λειτουργία Καταλόγου. Ο συνδυασμός IIS+PHP/CGI είναι γνωστό ότι έχει τέτοιο πρόβλημα. Δείτε και <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> για λεπτομέρειες.';
$lang['xsendfile']             = 'Χρήση της κεφαλίδας X-Sendfile από τον εξυπηρετητή κατά την φόρτωση στατικών αρχείων? Ο εξυπηρετητής σας πρέπει να υποστηρίζει αυτή την δυνατότητα.';
$lang['renderer_xhtml']        = 'Πρόγραμμα δημιουργίας βασικής (xhtml) εξόδου wiki.';
$lang['renderer__core']        = '%s (βασικός κώδικας dokuwiki)';
$lang['renderer__plugin']      = '%s (επέκταση)';
$lang['dnslookups']            = 'Το DokuWiki θα ψάξει τα ονόματα υπολογιστών που αντιστοιχούν σε διευθύνσεις IP των χρηστών που γράφουν στις σελίδες. Αν ο DNS είναι αργός, δεν δουλεύει ή δεν χρειάζεστε αυτή την λειτουργία, απενεργοποιήστε την.';
$lang['proxy____host']         = 'Διακομιστής Proxy';
$lang['proxy____port']         = 'Θύρα Proxy';
$lang['proxy____user']         = 'Όνομα χρήστη Proxy';
$lang['proxy____pass']         = 'Κωδικός χρήστη Proxy';
$lang['proxy____ssl']          = 'Χρήση ssl για σύνδεση με διακομιστή Proxy';
$lang['proxy____except']       = 'Regular expression για να πιάνει τα URLs για τα οποία θα παρακάμπτεται το proxy.';
$lang['safemodehack']          = 'Ενεργοποίηση safemode hack';
$lang['ftp____host']           = 'Διακομιστής FTP για safemode hack';
$lang['ftp____port']           = 'Θύρα FTP για safemode hack';
$lang['ftp____user']           = 'Όνομα χρήστη FTP για safemode hack';
$lang['ftp____pass']           = 'Κωδικός χρήστη FTP για safemode hack';
$lang['ftp____root']           = 'Αρχικός φάκελος FTP για safemode hack';
$lang['license_o_']            = 'Δεν επελέγει άδεια';
$lang['typography_o_0']        = 'κανένα';
$lang['typography_o_1']        = 'μόνο διπλά εισαγωγικά';
$lang['typography_o_2']        = 'όλα τα εισαγωγικά (μπορεί να μην λειτουργεί πάντα)';
$lang['userewrite_o_0']        = 'κανένα';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'από DokuWiki';
$lang['deaccent_o_0']          = 'όχι';
$lang['deaccent_o_1']          = 'αφαίρεση σημείων στίξης';
$lang['deaccent_o_2']          = 'λατινοποίηση';
$lang['gdlib_o_0']             = 'Δεν υπάρχει βιβλιοθήκη GD στο σύστημα';
$lang['gdlib_o_1']             = 'Έκδοση 1.x';
$lang['gdlib_o_2']             = 'Αυτόματος εντοπισμός';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Περίληψη';
$lang['rss_content_o_diff']    = 'Ενοποιημένο Diff';
$lang['rss_content_o_htmldiff'] = 'HTML διαμορφωμένος πίνακας diff';
$lang['rss_content_o_html']    = 'Περιεχόμενο Σελίδας μόνο με HTML';
$lang['rss_linkto_o_diff']     = 'προβολή αλλαγών';
$lang['rss_linkto_o_page']     = 'τροποποιημένη σελίδα';
$lang['rss_linkto_o_rev']      = 'εκδόσεις σελίδας';
$lang['rss_linkto_o_current']  = 'τρέχουσα σελίδα';
$lang['compression_o_0']       = 'none';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'να μην χρησιμοποιείται';
$lang['xsendfile_o_1']         = 'Ιδιοταγής κεφαλίδα lighttpd (πριν από την έκδοση 1.5)';
$lang['xsendfile_o_2']         = 'Τυπική κεφαλίδα X-Sendfile';
$lang['xsendfile_o_3']         = 'Ιδιοταγής κεφαλίδα Nginx X-Accel-Redirect ';
$lang['showuseras_o_loginname'] = 'Όνομα χρήστη';
$lang['showuseras_o_username'] = 'Ονοματεπώνυμο χρήστη';
$lang['showuseras_o_email']    = 'e-mail διεύθυνση χρήστη (εμφανίζεται σύμφωνα με την ρύθμιση για την κωδικοποίηση e-mail διευθύνσεων)';
$lang['showuseras_o_email_link'] = 'Εμφάνιση e-mail διεύθυνσης χρήστη σαν σύνδεσμος mailto:';
$lang['useheading_o_0']        = 'Ποτέ';
$lang['useheading_o_navigation'] = 'Μόνο κατά την πλοήγηση';
$lang['useheading_o_content']  = 'Μόνο για τα περιεχόμενα του wiki';
$lang['useheading_o_1']        = 'Πάντα';
$lang['readdircache']          = 'Μέγιστος χρόνος διατήρησης για το cache του readdir (δευτερόλεπτα)';
